@@ -495,7 +495,7 @@ notify_notification_new (const char *summary,
         return g_object_new (NOTIFY_TYPE_NOTIFICATION,
                              "summary", summary,
                              "body", body,
-                             "icon-name", icon,
+                             "app-icon", icon,
                              NULL);
 }
 
