@@ -35,14 +35,9 @@
 #include "internal.h"
 #include "notify-marshal.h"
 
-/**
- * SECTION:notify
- * @Short_description: Notification API
- * @Title: notify
- */
-
 static gboolean         _initted = FALSE;
 static char            *_app_name = NULL;
+static char            *_app_icon = NULL;
 static char            *_snap_name = NULL;
 static char            *_snap_app = NULL;
 static char            *_flatpak_app = NULL;
@@ -169,6 +164,21 @@ notify_set_app_name (const char *app_name)
         set_app_name (app_name);
 }
 
+/**
+ * notify_set_app_icon:
+ * @app_icon: (nullable): The optional icon theme icon name or filename.
+ *
+ * Sets the application icon.
+ *
+ * Since: 0.8.4
+ */
+void
+notify_set_app_icon (const char *app_icon)
+{
+        g_free (_app_icon);
+        _app_icon = g_strdup (app_icon);
+}
+
 /**
  * notify_init:
  * @app_name: (nullable): The name of the application initializing libnotify.
@@ -432,7 +442,7 @@ _notify_uses_portal_notifications (void)
  *
  * Gets the application name registered.
  *
- * Returns: The registered application name, passed to notify_init().
+ * Returns: The registered application name, passed to [func@init].
  */
 const char *
 notify_get_app_name (void)
@@ -440,10 +450,25 @@ notify_get_app_name (void)
         return _app_name;
 }
 
+/**
+ * notify_get_app_icon:
+ *
+ * Gets the application icon registered.
+ *
+ * Returns: The registered application icon, set via [func@set_app_icon].
+ *
+ * Since: 0.8.4
+ */
+const char *
+notify_get_app_icon (void)
+{
+        return _app_icon;
+}
+
 /**
  * notify_uninit:
  *
- * Uninitialized libnotify.
+ * Uninitializes libnotify.
  *
  * This should be called when the program no longer needs libnotify for
  * the rest of its lifecycle, typically just before exitting.
@@ -457,10 +482,7 @@ notify_uninit (void)
                 return;
         }
 
-        if (_app_name != NULL) {
-                g_free (_app_name);
-                _app_name = NULL;
-        }
+        g_clear_pointer (&_app_name, g_free);
 
         for (l = _active_notifications; l != NULL; l = l->next) {
                 NotifyNotification *n = NOTIFY_NOTIFICATION (l->data);
@@ -469,21 +491,14 @@ notify_uninit (void)
                     _notify_notification_has_nondefault_actions (n)) {
                         notify_notification_close (n, NULL);
                 }
+
+                g_object_run_dispose (G_OBJECT (n));
         }
 
-        if (_proxy != NULL) {
-            g_object_unref (_proxy);
-            _proxy = NULL;
-        }
-
-        g_free (_snap_name);
-        _snap_name = NULL;
-
-        g_free (_snap_app);
-        _snap_app = NULL;
-
-        g_free (_flatpak_app);
-        _flatpak_app = NULL;
+        g_clear_object (&_proxy);
+        g_clear_pointer (&_snap_name, g_free);
+        g_clear_pointer (&_snap_app, g_free);
+        g_clear_pointer (&_flatpak_app, g_free);
 
         _initted = FALSE;
 }
@@ -533,8 +548,8 @@ _get_portal_proxy (GError **error)
         _portal_version = g_variant_get_uint32 (res);
         g_assert (_portal_version > 0);
 
-        g_warning ("Running in confined mode, using Portal notifications. "
-                   "Some features and hints won't be supported");
+        g_debug ("Running in confined mode, using Portal notifications. "
+                 "Some features and hints won't be supported");
 
         g_variant_unref (res);
 
@@ -543,12 +558,12 @@ _get_portal_proxy (GError **error)
 
 /*
  * _notify_get_proxy:
- * @error: (allow-none): a location to store a #GError, or %NULL
+ * @error: (nullable): a location to store a #GError, or %NULL
  *
  * Synchronously creates the #GDBusProxy for the notification service,
  * and caches the result.
  *
- * Returns: the #GDBusProxy for the notification service, or %NULL on error
+ * Returns: (nullable): the #GDBusProxy for the notification service, or %NULL on error
  */
 GDBusProxy *
 _notify_get_proxy (GError **error)
@@ -579,8 +594,7 @@ out:
         }
 
         if (!_notify_update_spec_version (error)) {
-               g_object_unref (_proxy);
-               _proxy = NULL;
+               g_clear_object (&_proxy);
                return NULL;
         }
 
@@ -592,10 +606,12 @@ out:
 /**
  * notify_get_server_caps:
  *
- * Synchronously queries the server for its capabilities and returns them in a #GList.
+ * Queries the server capabilities.
  *
- * Returns: (transfer full) (element-type utf8): a #GList of server capability strings. Free
- *   the list elements with g_free() and the list itself with g_list_free().
+ * Synchronously queries the server for its capabilities and returns them in a
+ * list.
+ *
+ * Returns: (transfer full) (element-type utf8): a list of server capability strings.
  */
 GList *
 notify_get_server_caps (void)
@@ -649,17 +665,19 @@ notify_get_server_caps (void)
 
 /**
  * notify_get_server_info:
- * @ret_name: (out) (allow-none) (transfer full): a location to store the server name, or %NULL
- * @ret_vendor: (out) (allow-none) (transfer full): a location to store the server vendor, or %NULL
- * @ret_version: (out) (allow-none) (transfer full): a location to store the server version, or %NULL
- * @ret_spec_version: (out) (allow-none) (transfer full): a location to store the version the service is compliant with, or %NULL
+ * @ret_name: (out) (optional) (transfer full): a location to store the server name, or %NULL
+ * @ret_vendor: (out) (optional) (transfer full): a location to store the server vendor, or %NULL
+ * @ret_version: (out) (optional) (transfer full): a location to store the server version, or %NULL
+ * @ret_spec_version: (out) (optional) (transfer full): a location to store the version the service is compliant with, or %NULL
  *
- * Synchronously queries the server for its information, specifically, the name, vendor,
- * server version, and the version of the notifications specification that it
- * is compliant with.
+ * Queries the server for information.
+ *
+ * Synchronously queries the server for its information, specifically, the name,
+ * vendor, server version, and the version of the notifications specification
+ * that it is compliant with.
  *
  * Returns: %TRUE if successful, and the variables passed will be set, %FALSE
- *          on error. The returned strings must be freed with g_free
+ *   on error. The returned strings must be freed with g_free
  */
 gboolean
 notify_get_server_info (char **ret_name,
