@@ -228,11 +228,6 @@ validate_utf8_or_die (const char *str, const char *param)
 int
 main (int argc, char *argv[])
 {
-#ifdef g_autoptr
-        g_autoptr (NotifyNotification) notify = NULL;
-#else
-        NotifyNotification *notify = NULL;
-#endif
         static const char  *summary = NULL;
         char               *body;
         static const char  *type = NULL;
@@ -251,8 +246,9 @@ main (int argc, char *argv[])
         static gboolean     hint_error = FALSE, show_error = FALSE;
         static gboolean     transient = FALSE;
         static gboolean     wait = FALSE;
-        static glong        expire_timeout = NOTIFY_EXPIRES_DEFAULT;
+        static int          expire_timeout = NOTIFY_EXPIRES_DEFAULT;
         GOptionContext     *opt_ctx;
+        NotifyNotification *notify;
         GError             *error = NULL;
         gboolean            retval;
 
@@ -373,7 +369,7 @@ main (int argc, char *argv[])
         notify = g_object_new (NOTIFY_TYPE_NOTIFICATION,
                                "summary", summary,
                                "body", body,
-                               "icon-name", icon_str,
+                               "app-icon", icon_str,
                                "id", notification_id,
                                NULL);
 
@@ -510,9 +506,7 @@ main (int argc, char *argv[])
                 loop = NULL;
         }
 
-#ifndef g_autoptr
-        g_clear_object (&notify);
-#endif
+        g_object_unref (G_OBJECT (notify));
 
         notify_uninit ();
 
